@@ -1,7 +1,7 @@
-from .openapi_client import Configuration as OpenapiConfiguration
+from . import openapi_client
 from .servers import Servers
 
-class Configuration(OpenapiConfiguration):
+class Configuration(openapi_client.Configuration):
 
     def __init__(self, api_key, access_token=None, server: Servers = Servers.UNICATDB_ORG):
         self.access_token = access_token
@@ -14,13 +14,15 @@ class Configuration(OpenapiConfiguration):
     def auth_settings(self):
         auth = super().auth_settings()
 
-        auth['JwtAuth'] = {
-            'type': 'bearer',
-            'in': 'header',
-            'format': 'JWT',
-            'key': 'Authorization',
-            'value': 'Bearer ' + self.access_token
-        }
+        if self.access_token is not None:
+            auth['JwtAuth'] = {
+                'type': 'bearer',
+                'in': 'header',
+                'format': 'JWT',
+                'key': 'Authorization',
+                'value': 'Bearer ' + self.access_token
+            }
+
 
         return auth
 
